@@ -32,9 +32,10 @@ impl Helm {
     pub(crate) async fn execute(
         &self,
         cluster: &v0::Cluster,
+        kube_context: &str,
         namespace: &str,
     ) -> io::Result<(String, String)> {
-        let commands = self.command(cluster, namespace);
+        let commands = self.command(cluster, Some(kube_context), namespace);
         let (stdout, stderr) = match self {
             Helm::Skip { .. } => (
                 String::new(),
@@ -59,7 +60,12 @@ impl Helm {
         Ok((stdout, stderr))
     }
 
-    pub(crate) fn command(&self, cluster: &v0::Cluster, namespace: &str) -> Vec<Command> {
+    pub(crate) fn command(
+        &self,
+        cluster: &v0::Cluster,
+        kube_context: Option<&str>,
+        namespace: &str,
+    ) -> Vec<Command> {
         cluster
             .helm
             .iter()
@@ -77,6 +83,9 @@ impl Helm {
                 for (param, value) in &helm.parameters {
                     cmd.arg("--set").arg(format!("{}={}", param, value));
                 }
+                if let Some(kube_context) = kube_context {
+                    cmd.arg("--kube-context").arg(kube_context);
+                }
                 cmd
             })
             .collect()
