@@ -17,13 +17,13 @@ impl CloudRegion for GcpRegion {
 }
 
 impl str::FromStr for GcpRegion {
-    type Err = InvalidRegion;
+    type Err = InvalidLocation;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         let text = s.strip_prefix(Self::VENDOR_PREFIX).unwrap_or(s);
         match text {
             "antarctica" => Ok(Self::Antarctica),
-            other => Err(InvalidRegion::new(Self::VENDOR, other)),
+            other => Err(InvalidLocation::new(Self::VENDOR, other)),
         }
     }
 }
